%bcond_without test

%define module	pikepdf

Name:		python-%{module}
Version:	2.4.0
Release:	%mkrel 1
Summary:	Read and write PDFs with Python, powered by qpdf
Group:		Development/Python
License:	MPLv2.0
URL:		https://github.com/pikepdf/pikepdf
Source0:	https://pypi.io/packages/source/p/%{module}/%{module}-%{version}.tar.gz
Patch1:		0001-Relax-some-requirements.patch

BuildRequires:	gcc-c++
BuildRequires:	pkgconfig(libqpdf) >= 10.0.3
BuildRequires:	pkgconfig(python3)
BuildRequires:	pybind11-devel >= 2.6.1-2
BuildRequires:	python3dist(lxml) >= 4
BuildRequires:	python3dist(pybind11) >= 2.6
BuildRequires:	python3dist(pybind11) < 3
BuildRequires:	python3dist(setuptools)
BuildRequires:	python3dist(setuptools-scm)
BuildRequires:	python3dist(setuptools-scm[toml]) >= 4.1
BuildRequires:	python3dist(setuptools-scm-git-archive)
# Tests:
%if %{with test}
BuildRequires:	poppler
BuildRequires:	python3dist(attrs) >= 20.2
BuildRequires:	python3dist(hypothesis) >= 5
BuildRequires:	python3dist(hypothesis) < 6
BuildRequires:	python3dist(pillow) >= 7
BuildRequires:	python3dist(psutil) >= 5
BuildRequires:	python3dist(pytest) >= 6
BuildRequires:	python3dist(pytest) < 7
BuildRequires:	python3dist(pytest-runner)
BuildRequires:	python3dist(pytest-timeout) >= 1.4.2
BuildRequires:	python3dist(pytest-xdist) >= 1.28
BuildRequires:	python3dist(pytest-xdist) < 3
BuildRequires:	python3dist(python-xmp-toolkit) >= 2.0.1
%endif

%description
pikepdf is a Python library for reading and writing PDF files. pikepdf is
based on QPDF, a powerful PDF manipulation and repair library.


%package -n	python3-%{module}
Summary:	Read and write PDFs with Python3, powered by qpdf
Group:		Development/Python
%{?python_provide:%python_provide python3-%{module}}

%description -n	python3-%{module}
pikepdf is a Python 3 library for reading and writing PDF files. pikepdf
is based on QPDF, a powerful PDF manipulation and repair library.


%package -n	python-%{module}-doc
Summary:	pikepdf documentation
Group:		Documentation
BuildRequires:	python3dist(sphinx) >= 1.4
BuildRequires:	python3dist(sphinx-rtd-theme)
BuildRequires:	python3dist(pillow) >= 7
BuildRequires:	python3dist(matplotlib)
BuildRequires:	ipython

%description -n	python-%{module}-doc
Documentation for pikepdf.


%prep
%autosetup -n %{module}-%{version} -p1

# Remove bundled egg-info
rm -rf src/%{module}.egg-info

# We don't build docs against the installed version, so force the version.
sed -i -e "s/release = .\+/release = '%{version}'/g" docs/conf.py

%build
%py3_build

# generate html docs
pushd docs
PYTHONPATH=$(ls -d ${PWD}/../build/lib*) sphinx-build-3 . ../html
popd
# remove the sphinx-build leftovers
rm -rf html/.{doctrees,buildinfo}

%install
%py3_install

# ensure .so modules are executable for proper -debuginfo extraction
chmod a+rx %{buildroot}%{python3_sitearch}/%{module}/*.so

%check
%if %{with test}
%{pytest} -ra
%endif

%files -n python3-%{module}
%license LICENSE.txt
%doc README.md
%{python3_sitearch}/%{module}/
%{python3_sitearch}/%{module}-%{version}-py?.?.egg-info

%files -n python-%{module}-doc
%doc html
%license LICENSE.txt


%changelog
* Mon Jan 25 2021 daviddavid <daviddavid> 2.4.0-1.mga8
+ Revision: 1673248
- new version: 2.4.0 (fixes build against qpdf 10.1.0)

* Wed Dec 30 2020 daviddavid <daviddavid> 2.2.4-1.mga8
+ Revision: 1665554
- new version: 2.2.4

* Tue Dec 29 2020 daviddavid <daviddavid> 2.2.3-1.mga8
+ Revision: 1664705
- new version: 2.2.3

* Fri Dec 25 2020 daviddavid <daviddavid> 2.2.2-1.mga8
+ Revision: 1663649
- new version: 2.2.2

* Wed Oct 28 2020 daviddavid <daviddavid> 1.19.3-2.mga8
+ Revision: 1640098
- relax pytest dependency
- relax pytest-xdist dependency

* Fri Sep 11 2020 daviddavid <daviddavid> 1.19.3-1.mga8
+ Revision: 1624666
- new version: 1.19.3

* Mon Sep 07 2020 daviddavid <daviddavid> 1.19.1-1.mga8
+ Revision: 1623302
- new version: 1.19.1

* Tue Aug 25 2020 daviddavid <daviddavid> 1.19.0-1.mga8
+ Revision: 1618833
- new version: 1.19.0

* Tue Aug 18 2020 daviddavid <daviddavid> 1.18.0-1.mga8
+ Revision: 1614725
- new version: 1.18.0

* Sun Aug 02 2020 daviddavid <daviddavid> 1.17.3-1.mga8
+ Revision: 1610484
- new version: 1.17.3

* Fri Jul 17 2020 daviddavid <daviddavid> 1.17.2-1.mga8
+ Revision: 1606709
- new version: 1.17.2

* Tue Jul 14 2020 daviddavid <daviddavid> 1.17.1-1.mga8
+ Revision: 1605895
- new version: 1.17.1

* Sat Jul 04 2020 daviddavid <daviddavid> 1.16.1-1.mga8
+ Revision: 1601803
- new version: 1.16.1

* Sun Jun 21 2020 daviddavid <daviddavid> 1.15.1-1.mga8
+ Revision: 1598275
- new version: 1.15.1

* Sun Jun 21 2020 daviddavid <daviddavid> 1.15.0-1.mga8
+ Revision: 1598248
- new version: 1.15.0

* Mon Jun 01 2020 daviddavid <daviddavid> 1.14.0-2.mga8
+ Revision: 1589443
- enable testsuite

* Mon Jun 01 2020 daviddavid <daviddavid> 1.14.0-1.mga8
+ Revision: 1589351
- new version: 1.14.0

* Mon May 18 2020 daviddavid <daviddavid> 1.13.0-1.mga8
+ Revision: 1585989
- new version: 1.13.0

* Sun May 17 2020 daviddavid <daviddavid> 1.12.0-1.mga8
+ Revision: 1585457
- new version: 1.12.0

* Wed May 06 2020 daviddavid <daviddavid> 1.11.2-1.mga8
+ Revision: 1580730
- new version: 1.11.2

* Fri Apr 17 2020 daviddavid <daviddavid> 1.11.1-1.mga8
+ Revision: 1567977
- new version: 1.11.1

* Tue Apr 14 2020 tv <tv> 1.11.0-2.mga8
+ Revision: 1567334
- rebuild for new qpdf

* Mon Apr 13 2020 daviddavid <daviddavid> 1.11.0-1.mga8
+ Revision: 1567053
- new version: 1.11.0

* Thu Apr 02 2020 daviddavid <daviddavid> 1.10.4-1.mga8
+ Revision: 1563979
- new version: 1.10.4

* Thu Mar 19 2020 daviddavid <daviddavid> 1.10.3-1.mga8
+ Revision: 1557911
- new version: 1.10.3

* Sat Feb 29 2020 daviddavid <daviddavid> 1.10.2-1.mga8
+ Revision: 1552191
- new version: 1.10.2

* Fri Feb 21 2020 umeabot <umeabot> 1.10.1-2.mga8
+ Revision: 1547791
- Mageia 8 Mass Rebuild

* Tue Feb 18 2020 daviddavid <daviddavid> 1.10.1-1.mga8
+ Revision: 1541910
- new version: 1.10.1

* Mon Feb 10 2020 daviddavid <daviddavid> 1.10.0-1.mga8
+ Revision: 1488390
- disable test suite for now
- initial package python-pikepdf (needed for pdfarranger)

